"""
Synthetic data generation methods.

This module contains various methods for generating synthetic data,
each with different strengths and characteristics.

Available methods:
- Gaussian Copula: Models dependencies using multivariate Gaussian distributions
- (More methods to be added in future versions)
"""

from .gaussian_copula import GaussianCopulaGenerator
